summaryrefslogtreecommitdiff
path: root/lockfile.h
diff options
context:
space:
mode:
authorTaylor Blau <me@ttaylorr.com>2020-04-27 16:27:58 (GMT)
committerJunio C Hamano <gitster@pobox.com>2020-04-27 18:27:36 (GMT)
commitfa3bff2466ece4a10ba9beb9be3b45bada1c12eb (patch)
tree1c5c1aa21de73e052d1f2127d5507de5450b9135 /lockfile.h
parentbef0413c3595acb469cc212792c12b7106048ddc (diff)
downloadgit-fa3bff2466ece4a10ba9beb9be3b45bada1c12eb.zip
git-fa3bff2466ece4a10ba9beb9be3b45bada1c12eb.tar.gz
git-fa3bff2466ece4a10ba9beb9be3b45bada1c12eb.tar.bz2
lockfile.c: introduce 'hold_lock_file_for_update_mode'
We use 'hold_lock_file_for_update' (and the '_timeout') variant to acquire a lock when updating references, the commit-graph file, and so on. In particular, the commit-graph machinery uses this to acquire a temporary file that is used to write a non-split commit-graph. In a subsequent commit, an issue in the commit-graph machinery produces graph files that have a different permission based on whether or not they are part of a multi-layer graph will be addressed. To do so, the commit-graph machinery will need a version of 'hold_lock_file_for_update' that takes the permission bits from the caller. Introduce such a function in this patch for both the 'hold_lock_file_for_update' and 'hold_lock_file_for_update_timeout' functions, and leave the existing functions alone by inlining their definitions in terms of the new mode variants. Note that, like in the previous commit, 'hold_lock_file_for_update_mode' is not guarenteed to set the given mode, since it may be modified by both the umask and 'core.sharedRepository'. Note also that even though the commit-graph machinery only calls 'hold_lock_file_for_update', that this is defined in terms of 'hold_lock_file_for_update_timeout', and so both need an additional mode parameter here. Signed-off-by: Taylor Blau <me@ttaylorr.com> Signed-off-by: Junio C Hamano <gitster@pobox.com>
Diffstat (limited to 'lockfile.h')
-rw-r--r--lockfile.h32
1 files changed, 28 insertions, 4 deletions
diff --git a/lockfile.h b/lockfile.h
index 9843053..db93e6b 100644
--- a/lockfile.h
+++ b/lockfile.h
@@ -90,6 +90,15 @@
* functions. In particular, the state diagram and the cleanup
* machinery are all implemented in the tempfile module.
*
+ * Permission bits
+ * ---------------
+ *
+ * If you call either `hold_lock_file_for_update_mode` or
+ * `hold_lock_file_for_update_timeout_mode`, you can specify a suggested
+ * mode for the underlying temporary file. Note that the file isn't
+ * guaranteed to have this exact mode, since it may be limited by either
+ * the umask, 'core.sharedRepository', or both. See `adjust_shared_perm`
+ * for more.
*
* Error handling
* --------------
@@ -156,12 +165,20 @@ struct lock_file {
* file descriptor for writing to it, or -1 on error. If the file is
* currently locked, retry with quadratic backoff for at least
* timeout_ms milliseconds. If timeout_ms is 0, try exactly once; if
* timeout_ms is -1, retry indefinitely. The flags argument and error
* handling are described above.
*/
-int hold_lock_file_for_update_timeout(
+int hold_lock_file_for_update_timeout_mode(
+ struct lock_file *lk, const char *path,
+ int flags, long timeout_ms, int mode);
+
+static inline int hold_lock_file_for_update_timeout(
struct lock_file *lk, const char *path,
- int flags, long timeout_ms);
+ int flags, long timeout_ms)
+{
+ return hold_lock_file_for_update_timeout_mode(lk, path, flags,
+ timeout_ms, 0666);
+}
/*
* Attempt to create a lockfile for the file at `path` and return a
@@ -175,6 +192,13 @@ static inline int hold_lock_file_for_update(
return hold_lock_file_for_update_timeout(lk, path, flags, 0);
}
+static inline int hold_lock_file_for_update_mode(
+ struct lock_file *lk, const char *path,
+ int flags, int mode)
+{
+ return hold_lock_file_for_update_timeout_mode(lk, path, flags, 0, mode);
+}
+
/*
* Return a nonzero value iff `lk` is currently locked.
*/
@@ -156,12 +165,20 @@ struct lock_file {
* currently locked, retry with quadratic backoff for at least
* timeout_ms milliseconds. If timeout_ms is 0, try exactly once; if
- * timeout_ms is -1, retry indefinitely. The flags argument and error
- * handling are described above.
+ * timeout_ms is -1, retry indefinitely. The flags argument, error
+ * handling, and mode are described above.
*/